( cd usr/lib ; rm -rf libgal-a11y-2.0.so.6 )
( cd usr/lib ; ln -sf libgal-a11y-2.0.so.6.0.0 libgal-a11y-2.0.so.6 )
( cd usr/lib ; rm -rf libgal-a11y-2.0.so )
( cd usr/lib ; ln -sf libgal-a11y-2.0.so.6.0.0 libgal-a11y-2.0.so )
( cd usr/lib ; rm -rf libgal-2.0.so.6 )
( cd usr/lib ; ln -sf libgal-2.0.so.6.0.0 libgal-2.0.so.6 )
( cd usr/lib ; rm -rf libgal-2.0.so )
( cd usr/lib ; ln -sf libgal-2.0.so.6.0.0 libgal-2.0.so )
