/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/* 
 * e-table-defines.h
 * Copyright 2000, 2001, Ximian, Inc.
 *
 * Authors:
 *   Chris Lahey <clahey@ximian.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License, version 2, as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#ifndef __E_TABLE_DEFINES__
#define __E_TABLE_DEFINES__ 1

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define BUTTON_HEIGHT        10
#define BUTTON_PADDING       2
#define GROUP_INDENT         (BUTTON_HEIGHT + (BUTTON_PADDING * 2))

/* Padding around the contents of a header button */
#define HEADER_PADDING 1

#define MIN_ARROW_SIZE 10

#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif
